-- Creación de un procedimiento almacenado
-- donde encapsulamos todas las sentencias de código SQL necesarias 
-- para generar un reporte de todas las peliculas de origen en estados unidos 'USA'
CREATE PROCEDURE `sp_generar_reporte_peliculas`()
BEGIN
-- Creación de una tabla temporal para almacenar la información inicial
-- que extraemos dela base de datos.
CREATE TEMPORARY TABLE reporte_temporal (
  id INT NOT NULL AUTO_INCREMENT,
  idPelicula INT, 
  nombrePelicula VARCHAR(300), 
  nombreDirector VARCHAR(300),
  sinopsis VARCHAR(1500),
  fechaEstreno DATE,
  nombreDiaEstreno VARCHAR(25),
  codigoPais VARCHAR(3),
  duracionHoras DECIMAL(6,2),
  calificacion DECIMAL(2,1),
  valoracion VARCHAR(25),
  clasificacion VARCHAR(50), 
  PRIMARY KEY (id)
);

-- extracción de la información original y sin procesar por medio de una consulta
INSERT INTO reporte_temporal (idPelicula, 
  nombrePelicula, 
  nombreDirector,
  sinopsis, 
  fechaEstreno, 
  codigoPais, 
  duracionHoras, 
  calificacion, 
  clasificacion)
SELECT p.id,
  pn.nombre,
  CONCAT(d.nombre,' ', d.apellido),
  p.sinopsis,
  p.fechaEstreno,
  p.codigoPais,
  p.duracion,
  p.calificacion, 
  P.clasificacion
FROM pelicula AS p
INNER JOIN pelicula_nombre AS pn ON pn.PELICULA_id = p.id
INNER JOIN director AS d ON d.id = p.DIRECTOR_id
WHERE p.codigopais = 'USA';

-- procesamiento, calculos, transformacion de la informacion
UPDATE reporte_temporal SET
  nombrePelicula = UPPER(nombrePelicula), 
  nombreDirector = UPPER(nombreDirector);

UPDATE reporte_temporal SET 
  sinopsis = LPAD(sinopsis,50,'.');

UPDATE reporte_temporal SET
  nombreDiaEstreno =  CASE DAYNAME(fechaEstreno)
						WHEN 'Monday' THEN 'Lunes'
						WHEN 'Tuesday' THEN 'Martes'
						WHEN 'Wednesday' THEN 'Miercoles'
						WHEN 'Thursday' THEN 'Jueves'
						WHEN 'Friday' THEN 'Viernes'
						WHEN 'Saturday' THEN 'Sabado'
						ELSE 'Domingo'
					  END;
                      
UPDATE reporte_temporal 
SET 
  duracionHoras = duracionHoras / 60;

UPDATE reporte_temporal SET
  valoracion = IF(calificacion >= 3.5, 'BUENA', 'MALA');
  
-- Mostramos o almacenamos la información procesada.
select * from reporte_temporal;

-- al finalizar todo, borramos de una vez la información temporal para liberar
-- espacio en memoria
DROP TABLE reporte_temporal;
END


--
--
-- Llamado al procedimiento:
-- utilizando la instrucción CALL
-- 
-- 
USE bd_peliculas;
CALL sp_generar_reporte_peliculas();